@@ -173,17 +173,17 @@ class AGenericPage(Page):
         InlinePanel("language_pages", label="Pages multi-language")
     ]
 
-    edit_handler = TabbedInterface([
-        ObjectList(content_panels, heading='Content'),
-        ObjectList(promote_panels, heading='Promotion'),
-        ObjectList(settings_panels, heading='Settings'),
-        YoastPanel(
-            keywords='keywords',
-            title='seo_title',
-            search_description='search_description',
-            slug='slug'
-        ),
-    ])
+    # edit_handler = TabbedInterface([
+    #     ObjectList(content_panels, heading='Content'),
+    #     ObjectList(promote_panels, heading='Promotion'),
+    #     ObjectList(settings_panels, heading='Settings'),
+    #     YoastPanel(
+    #         keywords='keywords',
+    #         title='seo_title',
+    #         search_description='search_description',
+    #         slug='slug'
+    #     ),
+    # ])
 
     subpage_types = [
         'cms.ContentPage',
