@@ -1,7 +1,7 @@
 import logging
 import re
 from django import template
-
+from wagtail.core.blocks import StructValue
 from wagtail.embeds.embeds import get_embed
 from wagtail.embeds.exceptions import EmbedException
 
@@ -9,7 +9,8 @@ from webspace.loader import get_model
 from webspace.cms import constants
 
 register = template.Library()
-logger = logging.getLogger('forms')
+logger_form = logging.getLogger('forms')
+logger_cms = logging.getLogger('cms')
 IconSnippet = get_model('cms', 'IconSnippet')
 
 
@@ -94,13 +95,14 @@ def klass(ob):
 @register.filter
 def cached_form(form, request):
     if form:
-        if 'current_form_id' in request.session and request.session['current_form_id'] and form.id == request.session[
-            'current_form_id']:
-            logger.debug("Take form cached")
+        if 'current_form_id' in request.session \
+                and request.session['current_form_id'] \
+                and form.id == request.session['current_form_id']:
+            logger_form.debug("Take form cached")
             return form.get_form(request.POST, request.FILES, user=request.user)
-        logger.debug("Take new form")
+        logger_form.debug("Take new form")
         return form.get_form()
-    logger.debug("No forms")
+    logger_form.debug("No forms")
     return []
 
 
@@ -139,8 +141,15 @@ def theme_reverse(theme):
     return theme + '-inverse'
 
 
+@register.filter
+def block_to_api(block):
+    if block and isinstance(block.value, StructValue):
+        return block.block.get_api_representation(block.value)
+    return ''
+
+
 @register.filter
 def debug(item):
     import pdb
     pdb.set_trace()
-    return
+    return item
